@@ -45,7 +45,7 @@ impl Arguments for MySqlArguments {
         self.null_bitmap.resize((index / 8) + 1, 0);
 
         if let IsNull::Yes = value.encode_nullable(&mut self.params) {
-            self.null_bitmap[index / 8] &= (1 << index % 8) as u8;
+            self.null_bitmap[index / 8] |= (1 << index % 8) as u8;
         }
     }
 }
