@@ -1,6 +1,7 @@
-use crate::io::{Buf, BufMut};
 use byteorder::NetworkEndian;
 
+use crate::io::BufMut;
+
 pub struct SslRequest;
 
 impl SslRequest {
